﻿using Infragistics.Controls.Schedules;
using Infragistics.Controls.Schedules.Primitives;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace TimeSlotHeight
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            Loaded += MainWindow_Loaded;
        }

        void MainWindow_Loaded(object sender, RoutedEventArgs e)
        {
            ObservableCollection<Resource> resources = new ObservableCollection<Resource>();
            Resource resAmanda = new Resource() { Id = "own1", Name = "Amanda" };
            resources.Add(resAmanda);

            ObservableCollection<ResourceCalendar> calendars = new ObservableCollection<ResourceCalendar>();
            ResourceCalendar calAmanda = new ResourceCalendar()
            {
                Id = "cal1",
                OwningResourceId = "own1"
            };
            calendars.Add(calAmanda);

            ObservableCollection<Appointment> appointments = new ObservableCollection<Appointment>();
            Appointment app1 = new Appointment()
            {
                Id = "t1",
                OwningResourceId = "own1",
                OwningCalendarId = "cal1",
                Subject = "Appointment 1",
                Description = "My first appointment",
                // Convert the date to universal time, because a time zone is not set
                // in this snippet    
                Start = DateTime.Today.AddHours(9).AddMinutes(12).ToUniversalTime(),
                End = DateTime.Today.AddHours(11).AddMinutes(42).ToUniversalTime()
            };
            appointments.Add(app1);
            Appointment app2 = new Appointment()
            {
                Id = "t2",
                OwningResourceId = "own1",
                OwningCalendarId = "cal1",
                Subject = "Appointment 2",
                Description = "My second appointment",
                // Convert the date to universal time, because a time zone is not set
                // in this snippet    
                Start = DateTime.Today.AddHours(10).AddMinutes(12).ToUniversalTime(),
                End = DateTime.Today.AddHours(11).AddMinutes(42).ToUniversalTime()
            };
            appointments.Add(app2);

            ListScheduleDataConnector dataConnector = new ListScheduleDataConnector();
            dataConnector.ResourceItemsSource = resources;
            dataConnector.ResourceCalendarItemsSource = calendars;
            dataConnector.AppointmentItemsSource = appointments;

            XamScheduleDataManager dataManager = new XamScheduleDataManager();
            dataManager.DataConnector = dataConnector;
            CalendarGroupCollection calGroups = dataManager.CalendarGroups;
            CalendarGroup calGroup = new CalendarGroup();
            calGroup.InitialCalendarIds = "own1[cal1]";
            calGroups.Add(calGroup);

            outlookView.DataManager = dataManager;
            outlookView.TimeslotInterval = TimeSpan.FromMinutes(15);
            outlookView.ShowWorkingHoursOnly = true;
        }
    }

    public class AppointmentChecker : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            var presenter = value as AppointmentPresenter;
            if (presenter.Parent is ScheduleActivityPanel)
                return double.NaN;

            if (parameter == null)
                return 15.0;
            else return (int)parameter;
        }

        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }
}
